@@ -26,20 +26,6 @@ class Flatpak(Application):
         super().__init__(component=flatpak_id, **kwargs)
 
 
-    def start_via_command(self, command=None, **kwargs):
-        """
-        Currently the safest and only option to run flatpak due to duplicated .desktop files
-
-        :type command: str
-        :param command: Command to use to start the flatpak application.
-
-        :param kwargs: :py:class:`application.Application.start_via_command` parameters.
-        """
-
-        command = command or f"flatpak run {self.component}"
-        super().start_via_command(command=command, **kwargs)
-
-
     def kill_application(self):
         """
         Killing via 'flatpak kill <flatpak_id>', sudo for @system flatpaks
@@ -83,6 +69,7 @@ class Flatpak(Application):
         if not self.desktop_file_exists:
             return
 
+        desktop_file = None
         if self.desktop_file_path:
             desktop_file = self.desktop_file_path
         else:
@@ -99,6 +86,8 @@ class Flatpak(Application):
         desktop_file_config.read(desktop_file)
 
         self.name = desktop_file_config.get("Desktop Entry", "name")
+        self.exec = f"flatpak run {self.component}"
+        self.icon = desktop_file_config.get("Desktop Entry", "icon", fallback=None)
 
 
     def is_running(self):
@@ -118,6 +107,12 @@ class Flatpak(Application):
 
             Make sure that the .rpm version of a tested flatpak is not installed
         """
+        rpms = run(f'rpm -qa | grep -i "{self.name}"')
+        if rpms:
+            print(
+                f'WARNING: a method could possibly start a non-flatpak application\n'
+                f'{self.name} is already instaled as .rpm: {rpms}'
+            )
 
         super().start_via_menu(kill)
 
